Package: fauxpas
Title: HTTP Error Helpers
Description: HTTP error helpers. Methods included for general purpose HTTP
    error handling, as well as individual methods for every HTTP status
    code, both via status code numbers as well as their descriptive names.
    Supports ability to adjust behavior to stop, message or warning.
    Includes ability to use custom whisker template to have any configuration
    of status code, short description, and verbose message. Currently
    supports integration with 'crul', 'curl', and 'httr'.
Version: 0.6.0
Authors@R: person("Scott", "Chamberlain", role = c("aut", "cre"),
    email = "myrmecocystus@gmail.com",
    comment = c(ORCID = "0000-0003-1444-9135"))
License: MIT + file LICENSE
URL: https://sckott.github.io/fauxpas/,
        https://github.com/sckott/fauxpas
BugReports: https://github.com/sckott/fauxpas/issues
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
Imports: R6 (>= 2.1.2), httpcode (>= 0.3.0), whisker
Suggests: crul (>= 0.5.0), curl (>= 2.2), httr (>= 1.2.0), testthat,
        knitr, rmarkdown
RoxygenNote: 7.3.3
X-schema.org-applicationCategory: Web
X-schema.org-keywords: http, https, API, web-services, curl, errors,
        error
NeedsCompilation: no
Packaged: 2026-02-19 23:57:43 UTC; sckott
Author: Scott Chamberlain [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1444-9135>)
Maintainer: Scott Chamberlain <myrmecocystus@gmail.com>
Repository: CRAN
Date/Publication: 2026-02-20 06:40:10 UTC
Built: R 4.6.0; ; 2026-04-25 17:36:22 UTC; unix
