# Generated by roxygen2: do not edit by hand

S3method(http,HttpResponse)
S3method(http,default)
S3method(http,list)
S3method(http,response)
S3method(http100,HttpResponse)
S3method(http100,default)
S3method(http100,list)
S3method(http100,response)
S3method(http101,HttpResponse)
S3method(http101,default)
S3method(http101,list)
S3method(http101,response)
S3method(http102,HttpResponse)
S3method(http102,default)
S3method(http102,list)
S3method(http102,response)
S3method(http200,HttpResponse)
S3method(http200,default)
S3method(http200,list)
S3method(http200,response)
S3method(http201,HttpResponse)
S3method(http201,default)
S3method(http201,list)
S3method(http201,response)
S3method(http202,HttpResponse)
S3method(http202,default)
S3method(http202,list)
S3method(http202,response)
S3method(http203,HttpResponse)
S3method(http203,default)
S3method(http203,list)
S3method(http203,response)
S3method(http204,HttpResponse)
S3method(http204,default)
S3method(http204,list)
S3method(http204,response)
S3method(http205,HttpResponse)
S3method(http205,default)
S3method(http205,list)
S3method(http205,response)
S3method(http206,HttpResponse)
S3method(http206,default)
S3method(http206,list)
S3method(http206,response)
S3method(http207,HttpResponse)
S3method(http207,default)
S3method(http207,list)
S3method(http207,response)
S3method(http208,HttpResponse)
S3method(http208,default)
S3method(http208,list)
S3method(http208,response)
S3method(http226,HttpResponse)
S3method(http226,default)
S3method(http226,list)
S3method(http226,response)
S3method(http300,HttpResponse)
S3method(http300,default)
S3method(http300,list)
S3method(http300,response)
S3method(http301,HttpResponse)
S3method(http301,default)
S3method(http301,list)
S3method(http301,response)
S3method(http302,HttpResponse)
S3method(http302,default)
S3method(http302,list)
S3method(http302,response)
S3method(http303,HttpResponse)
S3method(http303,default)
S3method(http303,list)
S3method(http303,response)
S3method(http304,HttpResponse)
S3method(http304,default)
S3method(http304,list)
S3method(http304,response)
S3method(http305,HttpResponse)
S3method(http305,default)
S3method(http305,list)
S3method(http305,response)
S3method(http306,HttpResponse)
S3method(http306,default)
S3method(http306,list)
S3method(http306,response)
S3method(http307,HttpResponse)
S3method(http307,default)
S3method(http307,list)
S3method(http307,response)
S3method(http308,HttpResponse)
S3method(http308,default)
S3method(http308,list)
S3method(http308,response)
S3method(http400,HttpResponse)
S3method(http400,default)
S3method(http400,list)
S3method(http400,response)
S3method(http401,HttpResponse)
S3method(http401,default)
S3method(http401,list)
S3method(http401,response)
S3method(http402,HttpResponse)
S3method(http402,default)
S3method(http402,list)
S3method(http402,response)
S3method(http403,HttpResponse)
S3method(http403,default)
S3method(http403,list)
S3method(http403,response)
S3method(http404,HttpResponse)
S3method(http404,default)
S3method(http404,list)
S3method(http404,response)
S3method(http405,HttpResponse)
S3method(http405,default)
S3method(http405,list)
S3method(http405,response)
S3method(http406,HttpResponse)
S3method(http406,default)
S3method(http406,list)
S3method(http406,response)
S3method(http407,HttpResponse)
S3method(http407,default)
S3method(http407,list)
S3method(http407,response)
S3method(http408,HttpResponse)
S3method(http408,default)
S3method(http408,list)
S3method(http408,response)
S3method(http409,HttpResponse)
S3method(http409,default)
S3method(http409,list)
S3method(http409,response)
S3method(http410,HttpResponse)
S3method(http410,default)
S3method(http410,list)
S3method(http410,response)
S3method(http411,HttpResponse)
S3method(http411,default)
S3method(http411,list)
S3method(http411,response)
S3method(http412,HttpResponse)
S3method(http412,default)
S3method(http412,list)
S3method(http412,response)
S3method(http413,HttpResponse)
S3method(http413,default)
S3method(http413,list)
S3method(http413,response)
S3method(http414,HttpResponse)
S3method(http414,default)
S3method(http414,list)
S3method(http414,response)
S3method(http415,HttpResponse)
S3method(http415,default)
S3method(http415,list)
S3method(http415,response)
S3method(http416,HttpResponse)
S3method(http416,default)
S3method(http416,list)
S3method(http416,response)
S3method(http417,HttpResponse)
S3method(http417,default)
S3method(http417,list)
S3method(http417,response)
S3method(http418,HttpResponse)
S3method(http418,default)
S3method(http418,list)
S3method(http418,response)
S3method(http419,HttpResponse)
S3method(http419,default)
S3method(http419,list)
S3method(http419,response)
S3method(http420,HttpResponse)
S3method(http420,default)
S3method(http420,list)
S3method(http420,response)
S3method(http421,HttpResponse)
S3method(http421,default)
S3method(http421,list)
S3method(http421,response)
S3method(http422,HttpResponse)
S3method(http422,default)
S3method(http422,list)
S3method(http422,response)
S3method(http423,HttpResponse)
S3method(http423,default)
S3method(http423,list)
S3method(http423,response)
S3method(http424,HttpResponse)
S3method(http424,default)
S3method(http424,list)
S3method(http424,response)
S3method(http425,HttpResponse)
S3method(http425,default)
S3method(http425,list)
S3method(http425,response)
S3method(http426,HttpResponse)
S3method(http426,default)
S3method(http426,list)
S3method(http426,response)
S3method(http428,HttpResponse)
S3method(http428,default)
S3method(http428,list)
S3method(http428,response)
S3method(http429,HttpResponse)
S3method(http429,default)
S3method(http429,list)
S3method(http429,response)
S3method(http431,HttpResponse)
S3method(http431,default)
S3method(http431,list)
S3method(http431,response)
S3method(http440,HttpResponse)
S3method(http440,default)
S3method(http440,list)
S3method(http440,response)
S3method(http444,HttpResponse)
S3method(http444,default)
S3method(http444,list)
S3method(http444,response)
S3method(http449,HttpResponse)
S3method(http449,default)
S3method(http449,list)
S3method(http449,response)
S3method(http450,HttpResponse)
S3method(http450,default)
S3method(http450,list)
S3method(http450,response)
S3method(http451,HttpResponse)
S3method(http451,default)
S3method(http451,list)
S3method(http451,response)
S3method(http494,HttpResponse)
S3method(http494,default)
S3method(http494,list)
S3method(http494,response)
S3method(http495,HttpResponse)
S3method(http495,default)
S3method(http495,list)
S3method(http495,response)
S3method(http496,HttpResponse)
S3method(http496,default)
S3method(http496,list)
S3method(http496,response)
S3method(http497,HttpResponse)
S3method(http497,default)
S3method(http497,list)
S3method(http497,response)
S3method(http498,HttpResponse)
S3method(http498,default)
S3method(http498,list)
S3method(http498,response)
S3method(http499,HttpResponse)
S3method(http499,default)
S3method(http499,list)
S3method(http499,response)
S3method(http500,HttpResponse)
S3method(http500,default)
S3method(http500,list)
S3method(http500,response)
S3method(http501,HttpResponse)
S3method(http501,default)
S3method(http501,list)
S3method(http501,response)
S3method(http502,HttpResponse)
S3method(http502,default)
S3method(http502,list)
S3method(http502,response)
S3method(http503,HttpResponse)
S3method(http503,default)
S3method(http503,list)
S3method(http503,response)
S3method(http504,HttpResponse)
S3method(http504,default)
S3method(http504,list)
S3method(http504,response)
S3method(http505,HttpResponse)
S3method(http505,default)
S3method(http505,list)
S3method(http505,response)
S3method(http506,HttpResponse)
S3method(http506,default)
S3method(http506,list)
S3method(http506,response)
S3method(http507,HttpResponse)
S3method(http507,default)
S3method(http507,list)
S3method(http507,response)
S3method(http508,HttpResponse)
S3method(http508,default)
S3method(http508,list)
S3method(http508,response)
S3method(http509,HttpResponse)
S3method(http509,default)
S3method(http509,list)
S3method(http509,response)
S3method(http510,HttpResponse)
S3method(http510,default)
S3method(http510,list)
S3method(http510,response)
S3method(http511,HttpResponse)
S3method(http511,default)
S3method(http511,list)
S3method(http511,response)
S3method(http520,HttpResponse)
S3method(http520,default)
S3method(http520,list)
S3method(http520,response)
S3method(http521,HttpResponse)
S3method(http521,default)
S3method(http521,list)
S3method(http521,response)
S3method(http522,HttpResponse)
S3method(http522,default)
S3method(http522,list)
S3method(http522,response)
S3method(http523,HttpResponse)
S3method(http523,default)
S3method(http523,list)
S3method(http523,response)
S3method(http524,HttpResponse)
S3method(http524,default)
S3method(http524,list)
S3method(http524,response)
S3method(http525,HttpResponse)
S3method(http525,default)
S3method(http525,list)
S3method(http525,response)
S3method(http526,HttpResponse)
S3method(http526,default)
S3method(http526,list)
S3method(http526,response)
S3method(http527,HttpResponse)
S3method(http527,default)
S3method(http527,list)
S3method(http527,response)
S3method(http598,HttpResponse)
S3method(http598,default)
S3method(http598,list)
S3method(http598,response)
S3method(http599,HttpResponse)
S3method(http599,default)
S3method(http599,list)
S3method(http599,response)
export(Error)
export(HTTPATimeoutOccurred)
export(HTTPAccepted)
export(HTTPAlreadyReported)
export(HTTPAuthenticationTimeout)
export(HTTPBadGateway)
export(HTTPBadRequest)
export(HTTPBandwidthLimitExceeded)
export(HTTPBlockedByWindowsParentalControls)
export(HTTPCertError)
export(HTTPClientClosedRequest)
export(HTTPConflict)
export(HTTPConnectionTimedOut)
export(HTTPContinue)
export(HTTPCreated)
export(HTTPExpectationFailed)
export(HTTPFailedDependency)
export(HTTPForbidden)
export(HTTPFound)
export(HTTPGatewayTimeout)
export(HTTPGone)
export(HTTPHTTPToHTTPS)
export(HTTPHTTPVersionNotSupported)
export(HTTPImUsed)
export(HTTPInsufficientStorage)
export(HTTPInternalServerError)
export(HTTPInvalidSSLCertificate)
export(HTTPLengthRequired)
export(HTTPLocked)
export(HTTPLoginTimeout)
export(HTTPLoopDetected)
export(HTTPMethodFailure)
export(HTTPMethodNotAllowed)
export(HTTPMisdirectedRequest)
export(HTTPMovedPermanently)
export(HTTPMultiStatus)
export(HTTPMultipleChoices)
export(HTTPNetworkAuthenticationRequired)
export(HTTPNetworkConnectTimeoutError)
export(HTTPNetworkReadTimeoutError)
export(HTTPNoCert)
export(HTTPNoContent)
export(HTTPNoResponse)
export(HTTPNonAuthoritativeInformation)
export(HTTPNotAcceptable)
export(HTTPNotExtended)
export(HTTPNotFound)
export(HTTPNotImplemented)
export(HTTPNotModified)
export(HTTPOK)
export(HTTPOriginIsUnreachable)
export(HTTPPartialContent)
export(HTTPPaymentRequired)
export(HTTPPermanentRedirect)
export(HTTPPreconditionFailed)
export(HTTPPreconditionRequired)
export(HTTPProcessing)
export(HTTPProxyAuthenticationRequired)
export(HTTPRailgunError)
export(HTTPRequestEntityTooLarge)
export(HTTPRequestHeaderFieldsTooLarge)
export(HTTPRequestHeaderTooLarge)
export(HTTPRequestRangeNotSatisfiable)
export(HTTPRequestTimeout)
export(HTTPRequestURITooLong)
export(HTTPResetContent)
export(HTTPRetryWith)
export(HTTPSSLHandshakeFailed)
export(HTTPSeeOther)
export(HTTPServiceUnavailable)
export(HTTPSwitchProtocol)
export(HTTPSwitchProxy)
export(HTTPTeaPot)
export(HTTPTemporaryRedirect)
export(HTTPTokenExpiredInvalid)
export(HTTPTooManyRequests)
export(HTTPUnauthorized)
export(HTTPUnavailableForLegalReasons)
export(HTTPUnorderedCollection)
export(HTTPUnprocessableEntity)
export(HTTPUnsupportedMediaType)
export(HTTPUpgradeRequired)
export(HTTPUseProxy)
export(HTTPVariantAlsoNegotiates)
export(HTTPWebServerIsDown)
export(HTTPWebServerReturnedUnknownError)
export(find_error_class)
export(http)
export(http100)
export(http101)
export(http102)
export(http200)
export(http201)
export(http202)
export(http203)
export(http204)
export(http205)
export(http206)
export(http207)
export(http208)
export(http226)
export(http300)
export(http301)
export(http302)
export(http303)
export(http304)
export(http305)
export(http306)
export(http307)
export(http308)
export(http400)
export(http401)
export(http402)
export(http403)
export(http404)
export(http405)
export(http406)
export(http407)
export(http408)
export(http409)
export(http410)
export(http411)
export(http412)
export(http413)
export(http414)
export(http415)
export(http416)
export(http417)
export(http418)
export(http419)
export(http420)
export(http421)
export(http422)
export(http423)
export(http424)
export(http425)
export(http426)
export(http428)
export(http429)
export(http431)
export(http440)
export(http444)
export(http449)
export(http450)
export(http451)
export(http494)
export(http495)
export(http496)
export(http497)
export(http498)
export(http499)
export(http500)
export(http501)
export(http502)
export(http503)
export(http504)
export(http505)
export(http506)
export(http507)
export(http508)
export(http509)
export(http510)
export(http511)
export(http520)
export(http521)
export(http522)
export(http523)
export(http524)
export(http525)
export(http526)
export(http527)
export(http598)
export(http599)
importFrom(R6,R6Class)
importFrom(httpcode,http_code)
importFrom(whisker,whisker.render)
